Git Product home page Git Product logo

Comments (2)

jabir366 avatar jabir366 commented on June 9, 2024

@svartalf I would be happy to contribute to fixing this issue

from heim.

jabir366 avatar jabir366 commented on June 9, 2024

With the bellow fix It compiled successfully

diff --git a/heim-host/src/os/linux.rs b/heim-host/src/os/linux.rs
index 01fb44c..61908a8 100644
--- a/heim-host/src/os/linux.rs
+++ b/heim-host/src/os/linux.rs
@@ -5,8 +5,8 @@ use std::net::IpAddr;
 use crate::Pid;

 cfg_if::cfg_if! {
-    // aarch64-unknown-linux-gnu has different type
-    if #[cfg(all(target_arch = "aarch64", not(target_family = "musl")))] {
+    // aarch64-unknown-linux-gnu and s390x has different type
+    if #[cfg(any(target_arch = "s390x",all(target_arch = "aarch64", not(target_family = "musl"))))] {
         /// User session ID.
         pub type SessionId = i64;
     } else {

@svartalf Kindly have a review and I will raise PR for the same

from heim.

Related Issues (20)

Recommend Projects

  • React photo React

    A declarative, efficient, and flexible JavaScript library for building user interfaces.

  • Vue.js photo Vue.js

    🖖 Vue.js is a progressive, incrementally-adoptable JavaScript framework for building UI on the web.

  • Typescript photo Typescript

    TypeScript is a superset of JavaScript that compiles to clean JavaScript output.

  • TensorFlow photo TensorFlow

    An Open Source Machine Learning Framework for Everyone

  • Django photo Django

    The Web framework for perfectionists with deadlines.

  • D3 photo D3

    Bring data to life with SVG, Canvas and HTML. 📊📈🎉

Recommend Topics

  • javascript

    JavaScript (JS) is a lightweight interpreted programming language with first-class functions.

  • web

    Some thing interesting about web. New door for the world.

  • server

    A server is a program made to process requests and deliver data to clients.

  • Machine learning

    Machine learning is a way of modeling and interpreting data that allows a piece of software to respond intelligently.

  • Game

    Some thing interesting about game, make everyone happy.

Recommend Org

  • Facebook photo Facebook

    We are working to build community through open source technology. NB: members must have two-factor auth.

  • Microsoft photo Microsoft

    Open source projects and samples from Microsoft.

  • Google photo Google

    Google ❤️ Open Source for everyone.

  • D3 photo D3

    Data-Driven Documents codes.